LongAllocationDescriptor

Struct LongAllocationDescriptor 

#[repr(C)]
pub struct LongAllocationDescriptor { pub extent_length: u32, pub logical_block_num: u32, pub partition_ref_num: u16, pub impl_use: [u8; 6], }
Available on crate feature sync only.
Long allocation descriptor (ECMA-167 4/14.14.2)

Used to reference data that may span multiple partitions

@hadris-spec ECMA-167:4/14.14.2 @hadris-compliance partial @hadris-note The layout is modeled and tested, but all partition-reference and extent semantics are not validated at this layer. @hadris-tests comprehensive_udf::test_allocation_descriptor_sizes @hadris-fuzz udf_read

Fields

extent_length: u32

Extent length (high 2 bits indicate type)

logical_block_num: u32

Logical block number

partition_ref_num: u16

Partition reference number

impl_use: [u8; 6]

Implementation use (6 bytes)

Implementations

Source

impl LongAllocationDescriptor

pub fn length(&self) -> u32

Get the extent length in bytes (excluding type bits)

pub fn extent_type(&self) -> ExtentType

Get the extent type

pub fn is_recorded(&self) -> bool

Check if this is a recorded and allocated extent

pub fn extent_location(&self) -> LbAddr

Get the extent location (legacy accessor)